==> data_prep_lab-0.1.0.tar.gz: data_prep_lab-0.1.0/doc/overview.md <==
# Data Processing Overview 
The Data Processing Framework is python-based and enables the 
application of "transforms" to data files (currently parquet) across a distributed 
[Ray](https://docs.ray.io/en/latest/index.html) cluster, enabling the
scalable processing/transformation of virtually unlimited amounts of data. 

The framework allows simple 1:1 transformation of parquet files, but also enables
more complex transformations requiring coordination among transforming nodes.
This might include operations such as de-duplification, merging, and splitting.
The framework uses a plugin-model for the primary functions.  The key ones for
developers of data transformation are:
* [Transformation](../src/data_processing/transform/table_transform.py) - a simple, easily-implemented interface defines
the specifics of a given data transformation.
* [Transform Configuration](../src/data_processing/ray/transform_runtime.py) - defines
the transform implementation and runtime classes, the 
command line arguments specific to transform, and the short name for the transform.
* [Transformation Runtime](../src/data_processing/ray/transform_runtime.py) - allows for customization of the Ray environment for the transformer.
This might include provisioning of shared memory objects or creation of additional actors.

To learn more consider the following:
* [Transform Tutorials](transform-tutorials.md)
* [Testing transformers with S3](using_s3_transformers.md)
* [Library Configuration](library-config.md)
* [Architecture Deep Dive](architecture.md)
* [Transform project root readme](../../transforms/README.md)

==> data_prep_lab-0.1.3.tar.gz: data_prep_lab-0.1.3/doc/overview.md <==
# Data Processing Overview 
The Data Processing Framework is python-based and enables the 
application of "transforms" to data files (currently parquet) across a distributed 
[Ray](https://docs.ray.io/en/latest/index.html) cluster, enabling the
scalable processing/transformation of virtually unlimited amounts of data. 

The framework allows simple 1:1 transformation of parquet files, but also enables
more complex transformations requiring coordination among transforming nodes.
This might include operations such as de-duplication, merging, and splitting.
The framework uses a plugin-model for the primary functions.  The key ones for
developers of data transformation are:
* [Transformation](../src/data_processing/transform/table_transform.py) - a simple, easily-implemented interface defines
the specifics of a given data transformation.
* [Transform Configuration](../src/data_processing/ray/transform_runtime.py) - defines
the transform implementation and runtime classes, the 
command line arguments specific to transform, and the short name for the transform.
* [Transformation Runtime](../src/data_processing/ray/transform_runtime.py) - allows for customization of the Ray environment for the transformer.
This might include provisioning of shared memory objects or creation of additional actors.

To learn more consider the following:
* [Transform Tutorials](transform-tutorials.md)
* [Testing transformers with S3](using_s3_transformers.md)
* [Library Configuration](library-config.md)
* [Architecture Deep Dive](architecture.md)
* [Transform project root readme](../../transforms/README.md)
